import numpy as np

import matplotlib as mpl
mpl.use("TkAgg")

import matplotlib.pyplot as plt
import matplotlib.animation as animation

import PyDIP as dip
import PyDIP.PyDIPviewer as dv

import time

dipDir = 'c:/rp/diplib/'

fnameDefault = dipDir + 'images/chromo3d.ics'
framesDefault = 16 # number of frames to show
fpsDefault = 1 # frames per second

def anim(fname, frames, fps):
    duration = frames/fps # duration of move in seconds
    interval = 1/fps*1000 # interval between frames in milliseconds

    print('Using file %s'%(fname))
    print('Showing %d frames in %2.1f seconds'%(frames, duration))
    img = dip.ImageReadICS(fname)
    sz = img.Sizes()
    print('Image size: %d x %d'%(sz[0],sz[1]))
    imgFrames = sz[2] # number of frames in image
    
    def handle_close(evt):
        print('Closed animation!')

    fig = plt.figure() #figsize = tuple(sz[:2])
    fig.canvas.mpl_connect('close_event', handle_close)
    
    mng = plt.get_current_fig_manager()
    mng.window.wm_geometry("1280x1024+1680+0")
    #mng.window.state('zoomed')

    plt.axis('off')
    
    movie = []

    print('Randomizing frames...')
    indx = list(range(((frames-1)//imgFrames+1)*imgFrames))
    indx = np.mod(indx, imgFrames)
    np.random.shuffle(indx)
    indx = indx[:frames]

    print('Preparing movie...')
    for i in indx:
        slide = img[:,:,int(i)].Squeeze()
        movie.append([plt.imshow(slide)])
    
    ani = animation.ArtistAnimation(fig, movie, interval=interval, repeat=False, blit=True)

    plt.show(block=False)
    plt.pause(duration+1) # extra second for initialisation of figure
    plt.close()

if __name__ == "__main__":
    # execute only if run as a script
    #import matplotlib as mpl
    #mpl.use("TkAgg")
    print('Test with chromo3d, 16 frames and 1 fps...')
    anim(fnameDefault, framesDefault, fpsDefault)